use macros::Responsable;
use serde::{Deserialize, Serialize};

#[derive(Debug, Serialize, Deserialize, Responsable)]
pub struct Pageable<D>
where
    D: Serialize,
{
    pub data: Vec<D>,
    pub total: i64,
    pub page: i64,
    #[serde(rename = "pageSize")]
    pub page_size: i64,
}

impl<D> Pageable<D>
where
    D: Serialize,
{
    pub fn new(data: Vec<D>, total: i64, page: i64, page_size: i64) -> Self {
        Pageable {
            data,
            total,
            page,
            page_size,
        }
    }
    pub fn empty(page: i64, page_size: i64) -> Self {
        Pageable {
            data: vec![],
            total: 0,
            page,
            page_size,
        }
    }
}
